@@ -5,7 +5,7 @@
  * license (see LICENSE, in pngcrush.c).
  */
 
-/* Special defines for pngcrush version 1.7.82 */
+/* Special defines for pngcrush version 1.7.83 */
 
 #ifndef PNGCRUSH_H
 #define PNGCRUSH_H
@@ -23,9 +23,6 @@
 #undef PNG_READ_ALPHA_MODE_SUPPORTED
 #undef PNG_READ_BGR_SUPPORTED
 #undef PNG_READ_COMPOSITE_NODIV_SUPPORTED
-#if PNG_LIBPNG_VER >= 10600
-#  undef PNG_READ_GAMMA_SUPPORTED
-#endif
 #define PNG_ERROR_TEXT_SUPPORTED
 #define PNG_READ_STRIP_16_TO_8_SUPPORTED
 #undef PNG_READ_SWAP_ALPHA_SUPPORTED
@@ -46,14 +43,12 @@
 #undef PNG_WRITE_SWAP_SUPPORTED
 #undef PNG_WRITE_WEIGHTED_FILTER_SUPPORTED
 
-#if PNG_LIBPNG_VER >= 10600
-#  undef PNG_SIMPLIFIED_READ_AFIRST_SUPPORTED
-#  undef PNG_SIMPLIFIED_READ_BGR_SUPPORTED
-#  undef PNG_SIMPLIFIED_READ_SUPPORTED
-#  undef PNG_SIMPLIFIED_WRITE_AFIRST_SUPPORTED
-#  undef PNG_SIMPLIFIED_WRITE_BGR_SUPPORTED
-#  undef PNG_SIMPLIFIED_WRITE_SUPPORTED
-#endif
+#undef PNG_SIMPLIFIED_READ_AFIRST_SUPPORTED
+#undef PNG_SIMPLIFIED_READ_BGR_SUPPORTED
+#undef PNG_SIMPLIFIED_READ_SUPPORTED
+#undef PNG_SIMPLIFIED_WRITE_AFIRST_SUPPORTED
+#undef PNG_SIMPLIFIED_WRITE_BGR_SUPPORTED
+#undef PNG_SIMPLIFIED_WRITE_SUPPORTED
 
 #if PNG_LIBPNG_VER < 10400
 /* This allows png_default_error() to return, when it is called after our
